@@ -19,7 +19,19 @@ scs.pl - run DBIx::SchemaChecksum
 
 =head1 VERSION
 
-version 1.001
+version 1.002
+
+=head1 USAGE
+
+Please run
+
+  scs.pl help
+
+to get information on available commands and command line options.
+
+=head1 SEE ALSO
+
+See C<perldoc DBIx::SchemaChecksum> for even more info.
 
 =head1 AUTHORS
 
